@@ -153,11 +153,13 @@ static batch_job_id_t batch_job_condor_submit (struct batch_queue *q, const char
 	int64_t cores  = 1;
 	int64_t memory = 1024;
 	int64_t disk   = 1024;
+	int64_t gpus   = 0;
 
 	if(resources) {
 		cores  = resources->cores  > -1 ? resources->cores  : cores;
 		memory = resources->memory > -1 ? resources->memory : memory;
 		disk   = resources->disk   > -1 ? resources->disk   : disk;
+ 		gpus   = resources->gpus   > -1 ? resources->gpus   : gpus;
 	}
 
 	/* convert disk to KB */
@@ -167,11 +169,17 @@ static batch_job_id_t batch_job_condor_submit (struct batch_queue *q, const char
 		fprintf(file, "request_cpus   = ifThenElse(%" PRId64 " > TotalSlotCpus, %" PRId64 ", TotalSlotCpus)\n", cores, cores);
 		fprintf(file, "request_memory = ifThenElse(%" PRId64 " > TotalSlotMemory, %" PRId64 ", TotalSlotMemory)\n", memory, memory);
 		fprintf(file, "request_disk   = ifThenElse((%" PRId64 ") > TotalSlotDisk, (%" PRId64 "), TotalSlotDisk)\n", disk, disk);
+		if(gpus>0) {
+			fprintf(file, "request_gpus   = ifThenElse((%" PRId64 ") > TotalSlotGpus, (%" PRId64 "), TotalSlotGpus)\n", gpus, gpus);
+		}
 	}
 	else {
 			fprintf(file, "request_cpus = %" PRId64 "\n", cores);
 			fprintf(file, "request_memory = %" PRId64 "\n", memory);
 			fprintf(file, "request_disk = %" PRId64 "\n", disk);
+			if(gpus>0) {
+				fprintf(file, "request_gpus = %" PRId64 "\n", gpus);
+			}
 	}
 
 	if(options) {
